@@ -2,6 +2,7 @@
 
 from __future__ import annotations
 
+from .mkerr import mk
 from ..exceptions import ClientException
 
 import httpx # pip install httpx
@@ -20,8 +21,9 @@ async def reply(client: type, rt: str, msgs: list, disabled: bool):
         "messages": msgs,
         "notificationDisabled": disabled
       })
-      #print(r) # Dev
+      print(r.json()) # Dev
+      resJson = r.json()
+      mk(resJson)
       return r
   except Exception as err:
     raise ClientException(err)
-
